@@ -8,23 +8,16 @@ OC.L10N.register(
     "Rename" : "Преименувай",
     "Move" : "Преместване",
     "Delete" : "Изтрий",
+    "Select all" : "Избери всички",
     "New" : "Нов",
     "New folder" : "Нова папка",
-    "Grid view" : "Решетъчен изглед",
-    "List view" : "Списъчен изглед",
-    "Select all" : "Избери всички",
     "Submit" : "Изпращане",
     "Cancel" : "Отказ",
     "All bookmarks" : "Всички отметки",
     "Recent" : "Последни",
     "Untagged" : "Без отметки",
-    "Add a bookmark" : "Добави отметка",
     "Import" : "Внасяне",
     "Export" : "Изнасяне",
-    "Recently added" : "Последно добавени",
-    "Alphabetically" : "По азбучен ред",
-    "Most visited" : "Най-посещавани",
-    "Last modified" : "Променена",
     "Bookmarklet" : "Скриптова отметка",
     "Clear data" : "Изчисти данните",
     "Delete all bookmarks" : "Изтрий всички отметки",
@@ -32,17 +25,15 @@ OC.L10N.register(
     "Title" : "Име",
     "Link" : "Връзка",
     "Tags" : "Етикети",
-    "Attachments" : "Прикачени файлове",
     "Notes" : "Бележки",
-    "{time} ago" : "преди {time}",
     "Owner" : "Създател",
     "Sharing" : "Споделяне",
     "Share link" : "Връзка за споделяне",
     "Copy link" : "Копирай връзката",
     "Allow editing" : "Разреши редактиране",
     "Link copied" : "Връзката е копирана",
-    "Select" : "Маркирай",
     "Privacy" : "Защита на лични данни",
+    "Add a bookmark" : "Добави отметка",
     "This URL is already bookmarked! Overwrite?" : "Този адрес е вече добавен към отметките! Искате ли да презапишете?",
     "Folder" : "Папка",
     "Save" : "Запиши"
