@@ -81,12 +81,10 @@ OC.L10N.register(
     "Import" : "Importa",
     "Export" : "Exporta",
     "Archive path" : "Camí de l'arxiu",
-    "Enter the path of a folder where bookmarked files should be stored" : "Introduïu el camí d'una carpeta on s'han d'emmagatzemar els fitxers marcats",
     "Client apps" : "Aplicacions de client",
     "Also check out the collection of client apps that integrate with this app: " : "Feu també un cop d'hora al conjunt d'aplicacions client que s'integren amb aquesta aplicació: ",
     "Install on home screen" : "Instal·la a la pantalla d'inici",
     "Bookmarklet" : "Miniaplicació d'adreces d'interès",
-    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Arrossegueu-lo a les adreces d'interès del navegador i feu-hi clic per afegir ràpidament una pàgina web a les adreces d'interès",
     "Add to {instanceName}" : "Afegeix a {instanceName}",
     "Clear data" : "Neteja les dades",
     "Permanently remove all bookmarks from your account." : "Suprimeix permanentment totes les adreces d'interès del vostre compte.",
