@@ -8,19 +8,14 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Select all" : "Seleccionar todo",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
-    "Grid view" : "Vista de cuadrícula",
-    "List view" : "Vista de lista",
-    "Select all" : "Seleccionar todo",
+    "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
-    "Add a bookmark" : "Agregar un marcador",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Agregado recientemente",
-    "Alphabetically" : "Alfabéticamente",
-    "Last modified" : "Última modificación",
     "Bookmarklet" : "Marcador a código ",
     "Clear data" : "Borrar datos",
     "Title" : "Título",
@@ -32,8 +27,8 @@ OC.L10N.register(
     "Share link" : "Compartir liga",
     "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
-    "Select" : "Seleccionar",
     "Privacy" : "Privacidad",
+    "Add a bookmark" : "Agregar un marcador",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
