@@ -17,27 +17,24 @@ OC.L10N.register(
     "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
     "No file provided for import" : "Importavimui nepateiktas joks failas",
     "Unsupported file type for import" : "Importavimui pateiktas nepalaikomas failo tipas",
-    "Recent Bookmarks" : "Paskiausi adresyno įrašai",
     "A Bookmark manager for Nextcloud" : "Adresyno tvarkytuvė, skirta Nextcloud",
     "Select bookmark" : "Pasirinkti adresyno įrašą",
     "Details" : "Išsamiau",
     "Rename" : "Pervadinti",
     "Move" : "Perkelti",
     "Delete" : "Ištrinti",
-    "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
-    "New" : "Nauja",
-    "New folder" : "Naujas aplankas",
-    "Grid view" : "Tinklelio rodinys",
-    "List view" : "Sąrašo rodinys",
     "Move selection" : "Perkelti žymėjimą",
     "Delete selection" : "Ištrinti žymėjimą",
     "Select all" : "Pažymėti viską",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
+    "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
+    "New" : "Nauja",
+    "New folder" : "Naujas aplankas",
+    "RSS feed copied" : "RSS kanalas nukopijuotas",
     "Enter a link" : "Įveskite nuorodą",
     "Enter folder title" : "Įveskite aplanko pavadinimą",
     "Shared by {user}" : "Bendrina {user}",
     "Do you really want to delete this folder?" : "Ar tikrai norite ištrinti šį aplanką?",
-    "Root folder" : "Šakninis aplankas",
     "Submit" : "Pateikti",
     "Cancel" : "Atsisakyti",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
@@ -46,14 +43,8 @@ OC.L10N.register(
     "Recent" : "Paskiausi",
     "Untagged" : "Be žymių",
     "No bookmarks here" : "Čia adresyno įrašų nėra",
-    "Add a bookmark" : "Pridėti adresyno įrašą",
     "Import" : "Importuoti",
     "Export" : "Eksportuoti",
-    "Sorting" : "Rikiavimas",
-    "Recently added" : "Paskiausiai pridėti",
-    "Alphabetically" : "Pagal abėcėlę",
-    "Most visited" : "Daugiausiai lankyti",
-    "Last modified" : "Paskutinis modifikavimas",
     "Client apps" : "Kliento programėlės",
     "Add to {instanceName}" : "Pridėti į {instanceName}",
     "Clear data" : "Išvalyti duomenis",
@@ -61,13 +52,8 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Ar tikrai norite ištrinti visus savo adresyno įrašus?",
     "Title" : "Pareigos",
     "Link" : "Nuoroda",
-    "Creation date" : "Sukūrimo data",
     "Tags" : "Žymės",
-    "Attachments" : "Priedai",
-    "Archived version" : "Archyvuota versija",
-    "Open archived file" : "Atverti archyvuotą failą",
     "Notes" : "Pastabos",
-    "{time} ago" : "Prieš {time}",
     "Owner" : "Savininkas",
     "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
@@ -79,20 +65,19 @@ OC.L10N.register(
     "Allow editing" : "Leisti redaguoti",
     "Remove share" : "Šalinti viešinį",
     "Link copied" : "Nuoroda nukopijuota",
-    "RSS feed copied" : "RSS kanalas nukopijuotas",
-    "Select" : "Pasirinkti",
-    "Previews" : "Peržiūros",
-    "Screeenly" : "Screeenly",
-    "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
-    "Screeenly API URL" : "Screeenly API URL",
-    "Screeenly API key" : "Screeenly API raktas",
     "Privacy" : "Privatumas",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Adresynas bandys apsilankyti jūsų pridedamose internetinėse svetainėse, kad automatiškai pridėtų informaciją apie jas.",
     "Enable accessing and collecting information from the web pages you add" : "Leisti apsilankyti ir rinkti iš saityno informaciją apie jūsų pridedamus internetinius puslapius",
     "Performance" : "Našumas",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Didžiausias, vienai paskyrai leidžiamas, adresyno įrašų skaičius. (0, kad būtų neribojama; pagal numatymą yra neribojama)",
+    "Previews" : "Peržiūros",
+    "Screeenly" : "Screeenly",
+    "You can either sign up for free at screeenly.com or setup your own server." : "Galite arba nemokamai užsiregistruoti adresu screeenly.com, arba nusistatyti savo asmeninį serverį.",
+    "Screeenly API URL" : "Screeenly API URL",
+    "Screeenly API key" : "Screeenly API raktas",
     "Failed to load settings" : "Nepavyko įkelti nustatymų",
     "Failed to save settings" : "Nepavyko įrašyti nustatymų",
+    "Add a bookmark" : "Pridėti adresyno įrašą",
     "This URL is already bookmarked! Overwrite?" : "Šis URL jau įtrauktas į adresyną! Perrašyti?",
     "Enter bookmark title" : "Įveskite adresyno įrašo pavadinimą",
     "Enter bookmark URL" : "Įveskite adresyno įrašo URL",
