@@ -4,20 +4,23 @@
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 import Vue from 'vue'
+import { Store } from 'vuex'
 import Tooltip from '@nextcloud/vue/dist/Directives/Tooltip'
 import App from './App'
 import router from './router'
 import store from './store/'
 import AppGlobal from './mixins/AppGlobal'
+import DropTarget from './directives/drop-target'
 import { subscribe } from '@nextcloud/event-bus'
 import { generateUrl } from '@nextcloud/router'
 
 Vue.mixin(AppGlobal)
 Vue.directive('tooltip', Tooltip)
+Vue.directive('drop-target', DropTarget)
 
 const BookmarksApp = (global.Bookmarks = new Vue({
 	el: '#content',
-	store,
+	store: new Store(store),
 	router,
 	created() {
 		subscribe('nextcloud:unified-search.search', ({ query }) => {
